@@ -12,9 +12,10 @@ def get_ffmpeg_version():
     except FileNotFoundError:
         return None
 
-    match = re.search("ffmpeg version \D?(\d+\.\d+\.\d+)", str(console_output))
-    groups = match.groups()
+    regex = r"ffmpeg version \D?(\d+(?:\.\d+)*)"
+    match = re.search(regex, str(console_output))
 
+    groups = match.groups()
     version = groups[0].split(".")
 
     return [int(version_part) for version_part in version]
